==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QAccessibleBridgePlugin_shell.h <==
#ifndef QACCESSIBLEBRIDGEPLUGIN_SHELL_H
#define QACCESSIBLEBRIDGEPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qaccessiblebridge.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAccessibleBridgePlugin_shell : public QAccessibleBridgePlugin, public QtJambiShellInterface
{
public:
    QAccessibleBridgePlugin_shell(QObject* parent0 = nullptr);
    ~QAccessibleBridgePlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAccessibleBridge* create(const QString& key0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleBridgePlugin_access : public QAccessibleBridgePlugin
{
    jobject __qt_create_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0);
};

#endif // QACCESSIBLEBRIDGEPLUGIN_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QAccessibleBridgePlugin_shell.h <==
#ifndef QACCESSIBLEBRIDGEPLUGIN_SHELL_H
#define QACCESSIBLEBRIDGEPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qaccessiblebridge.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAccessibleBridgePlugin_shell : public QAccessibleBridgePlugin, public QtJambiShellInterface
{
public:
    QAccessibleBridgePlugin_shell(QObject* parent0 = nullptr);
    ~QAccessibleBridgePlugin_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QAccessibleBridgePlugin_mshell;
    friend class QAccessibleBridgePlugin_oshell;
};


class QAccessibleBridgePlugin_mshell : public QAccessibleBridgePlugin_shell
{
public:
    using QAccessibleBridgePlugin_shell::QAccessibleBridgePlugin_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAccessibleBridgePlugin_oshell : public QAccessibleBridgePlugin_mshell
{
public:
    using QAccessibleBridgePlugin_mshell::QAccessibleBridgePlugin_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QAccessibleBridge* create(const QString& key0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleBridgePlugin_access : public QAccessibleBridgePlugin
{
    jobject __qt_create_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0);
};

#endif // QACCESSIBLEBRIDGEPLUGIN_SHELL_H
